"""
Objects used for retrieving artist information from Spotify
"""

from typing import Dict, List, Optional

from pydantic import BaseModel, Field

from .extra import Image


class SimplifiedArtist(BaseModel):
    """
    https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedartistobject
    """

    external_urls: Dict[str, str]
    href: str
    spotify_id: str = Field(alias="id")
    name: str
    spotify_type: str = Field(alias="type")
    uri: str


class Followers(BaseModel):
    """
    https://developer.spotify.com/documentation/web-api/reference/#object-followersobject
    """

    href: Optional[str]
    total: int


class Artist(SimplifiedArtist):
    """
    https://developer.spotify.com/documentation/web-api/reference/#object-artistobject
    """

    followers: Followers
    genres: List[str]
    images: List[Image]
    popularity: int
