"""
Objects used for paging Spotify results
"""

from typing import Any, Dict, List, Optional

from pydantic import BaseModel, Field


class Cursor(BaseModel):
    """
    https://developer.spotify.com/documentation/web-api/reference/#object-cursorobject
    """

    after: Optional[str]


class CursorPaging(BaseModel):
    """
    https://developer.spotify.com/documentation/web-api/reference/#object-cursorpagingobject
    """

    cursors: Cursor
    href: str
    items: List[Dict[str, Any]]
    limit: int
    next_href: Optional[str] = Field(alias="next")
    total: int


class Paging(BaseModel):
    "https://developer.spotify.com/documentation/web-api/reference/#object-pagingobject"

    href: str
    items: List[Dict[str, Any]]
    limit: int
    next_href: Optional[str] = Field(alias="next")
    offset: int
    previous_href: Optional[str] = Field(alias="previous")
    total: int
